==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/provider/ScriptExceptionRaisedException.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTEXCEPTIONRAISEDEXCEPTION_HPP_
#define _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTEXCEPTIONRAISEDEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTEXCEPTIONRAISEDEXCEPTION_HDL_
#include "com/sun/star/script/provider/ScriptExceptionRaisedException.hdl"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HPP_
#include "com/sun/star/script/provider/ScriptErrorRaisedException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif

namespace com { namespace sun { namespace star { namespace script { namespace provider {

inline ScriptExceptionRaisedException::ScriptExceptionRaisedException() SAL_THROW( () )
    : ::com::sun::star::script::provider::ScriptErrorRaisedException()
    , exceptionType()
{ }

inline ScriptExceptionRaisedException::ScriptExceptionRaisedException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::rtl::OUString& scriptName_, const ::rtl::OUString& language_, const ::sal_Int32& lineNum_, const ::rtl::OUString& exceptionType_) SAL_THROW( () )
    : ::com::sun::star::script::provider::ScriptErrorRaisedException(Message_, Context_, scriptName_, language_, lineNum_)
    , exceptionType(exceptionType_)
{ }

ScriptExceptionRaisedException::ScriptExceptionRaisedException(ScriptExceptionRaisedException const & the_other): ::com::sun::star::script::provider::ScriptErrorRaisedException(the_other), exceptionType(the_other.exceptionType) {}

ScriptExceptionRaisedException::~ScriptExceptionRaisedException() {}

ScriptExceptionRaisedException & ScriptExceptionRaisedException::operator =(ScriptExceptionRaisedException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::script::provider::ScriptErrorRaisedException::operator =(the_other);
    exceptionType = the_other.exceptionType;
    return *this;
}

} } } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::script::provider::ScriptExceptionRaisedException* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.script.provider.ScriptExceptionRaisedException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTEXCEPTIONRAISEDEXCEPTION_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/script/provider/ScriptExceptionRaisedException.hpp <==
#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTEXCEPTIONRAISEDEXCEPTION_HPP_
#define _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTEXCEPTIONRAISEDEXCEPTION_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTEXCEPTIONRAISEDEXCEPTION_HDL_
#include "com/sun/star/script/provider/ScriptExceptionRaisedException.hdl"
#endif

#ifndef _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTERRORRAISEDEXCEPTION_HPP_
#include "com/sun/star/script/provider/ScriptErrorRaisedException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif

namespace com { namespace sun { namespace star { namespace script { namespace provider {

inline ScriptExceptionRaisedException::ScriptExceptionRaisedException() SAL_THROW( () )
    : ::com::sun::star::script::provider::ScriptErrorRaisedException()
    , exceptionType()
{ }

inline ScriptExceptionRaisedException::ScriptExceptionRaisedException(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::rtl::OUString& scriptName_, const ::rtl::OUString& language_, const ::sal_Int32& lineNum_, const ::rtl::OUString& exceptionType_) SAL_THROW( () )
    : ::com::sun::star::script::provider::ScriptErrorRaisedException(Message_, Context_, scriptName_, language_, lineNum_)
    , exceptionType(exceptionType_)
{ }

ScriptExceptionRaisedException::ScriptExceptionRaisedException(ScriptExceptionRaisedException const & the_other): ::com::sun::star::script::provider::ScriptErrorRaisedException(the_other), exceptionType(the_other.exceptionType) {}

ScriptExceptionRaisedException::~ScriptExceptionRaisedException() {}

ScriptExceptionRaisedException & ScriptExceptionRaisedException::operator =(ScriptExceptionRaisedException const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::script::provider::ScriptErrorRaisedException::operator =(the_other);
    exceptionType = the_other.exceptionType;
    return *this;
}

} } } } }

namespace com { namespace sun { namespace star { namespace script { namespace provider {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::script::provider::ScriptExceptionRaisedException const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.script.provider.ScriptExceptionRaisedException" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::script::provider::ScriptExceptionRaisedException const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::script::provider::ScriptExceptionRaisedException >::get();
}

#endif // _COM_SUN_STAR_SCRIPT_PROVIDER_SCRIPTEXCEPTIONRAISEDEXCEPTION_HPP_
